Type: Package
Package: leaflet
Title: Create Interactive Web Maps with the JavaScript 'Leaflet'
        Library
Version: 2.2.3
Authors@R: c(
    person("Joe", "Cheng", , "joe@posit.co", role = "aut"),
    person("Barret", "Schloerke", , "barret@posit.co", role = "aut",
           comment = c(ORCID = "0000-0001-9986-114X")),
    person("Bhaskar", "Karambelkar", role = "aut"),
    person("Yihui", "Xie", role = "aut"),
    person("Garrick", "Aden-Buie", , "garrick@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7111-0077")),
    person("Hadley", "Wickham", role = "ctb"),
    person("Kenton", "Russell", role = "ctb"),
    person("Kent", "Johnson", role = "ctb"),
    person("Vladimir", "Agafonkin", role = c("ctb", "cph"),
           comment = "Leaflet library"),
    person("CloudMade", role = "cph",
           comment = "Leaflet library"),
    person("Leaflet contributors", role = "ctb",
           comment = "Leaflet library"),
    person("Brandon Copeland", role = c("ctb", "cph"),
           comment = "leaflet-measure plugin"),
    person("Joerg Dietrich", role = c("ctb", "cph"),
           comment = "Leaflet.Terminator plugin"),
    person("Benjamin Becquet", role = c("ctb", "cph"),
           comment = "Leaflet.MagnifyingGlass plugin"),
    person("Norkart AS", role = c("ctb", "cph"),
           comment = "Leaflet.MiniMap plugin"),
    person("L. Voogdt", role = c("ctb", "cph"),
           comment = "Leaflet.awesome-markers plugin"),
    person("Daniel Montague", role = c("ctb", "cph"),
           comment = "Leaflet.EasyButton plugin"),
    person("Kartena AB", role = c("ctb", "cph"),
           comment = "Proj4Leaflet plugin"),
    person("Robert Kajic", role = c("ctb", "cph"),
           comment = "leaflet-locationfilter plugin"),
    person("Mapbox", role = c("ctb", "cph"),
           comment = "leaflet-omnivore plugin"),
    person("Michael Bostock", role = c("ctb", "cph"),
           comment = "topojson"),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Create and customize interactive maps using the 'Leaflet'
    JavaScript library and the 'htmlwidgets' package. These maps can be
    used directly from the R console, from 'RStudio', in Shiny
    applications and R Markdown documents.
License: MIT + file LICENSE
URL: https://rstudio.github.io/leaflet/,
        https://github.com/rstudio/leaflet
BugReports: https://github.com/rstudio/leaflet/issues
Depends: R (>= 3.5)
Imports: crosstalk, htmltools, htmlwidgets (>= 1.5.4), jquerylib,
        leaflet.providers (>= 2.0.0), magrittr, methods, png, raster
        (>= 3.6.3), RColorBrewer, rlang, scales (>= 1.0.0), sf (>=
        0.9-6), stats, viridisLite, xfun
Suggests: knitr, maps, purrr, R6, RJSONIO, rmarkdown, s2, shiny (>=
        1.0.0), sp, terra, testthat (>= 3.0.0)
Config/Needs/website: dplyr, ncdf4, rnaturalearth,
        tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-02 15:28:47 UTC; garrick
Author: Joe Cheng [aut],
  Barret Schloerke [aut] (ORCID: <https://orcid.org/0000-0001-9986-114X>),
  Bhaskar Karambelkar [aut],
  Yihui Xie [aut],
  Garrick Aden-Buie [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7111-0077>),
  Hadley Wickham [ctb],
  Kenton Russell [ctb],
  Kent Johnson [ctb],
  Vladimir Agafonkin [ctb, cph] (Leaflet library),
  CloudMade [cph] (Leaflet library),
  Leaflet contributors [ctb] (Leaflet library),
  Brandon Copeland [ctb, cph] (leaflet-measure plugin),
  Joerg Dietrich [ctb, cph] (Leaflet.Terminator plugin),
  Benjamin Becquet [ctb, cph] (Leaflet.MagnifyingGlass plugin),
  Norkart AS [ctb, cph] (Leaflet.MiniMap plugin),
  L. Voogdt [ctb, cph] (Leaflet.awesome-markers plugin),
  Daniel Montague [ctb, cph] (Leaflet.EasyButton plugin),
  Kartena AB [ctb, cph] (Proj4Leaflet plugin),
  Robert Kajic [ctb, cph] (leaflet-locationfilter plugin),
  Mapbox [ctb, cph] (leaflet-omnivore plugin),
  Michael Bostock [ctb, cph] (topojson),
  Posit Software, PBC [cph, fnd]
Maintainer: Garrick Aden-Buie <garrick@posit.co>
Repository: CRAN
Date/Publication: 2025-09-04 07:40:02 UTC
Built: R 4.6.0; ; 2026-04-28 22:55:07 UTC; unix
