# Generated by roxygen2: do not edit by hand

S3method("[",leaflet_awesome_icon_set)
S3method("[",leaflet_icon_set)
S3method(metaData,SharedData)
S3method(metaData,SpatVector)
S3method(metaData,SpatialLinesDataFrame)
S3method(metaData,SpatialPointsDataFrame)
S3method(metaData,SpatialPolygonsDataFrame)
S3method(metaData,data.frame)
S3method(metaData,list)
S3method(metaData,map)
S3method(metaData,sf)
S3method(pointData,POINT)
S3method(pointData,SharedData)
S3method(pointData,SpatVector)
S3method(pointData,SpatialPoints)
S3method(pointData,SpatialPointsDataFrame)
S3method(pointData,data.frame)
S3method(pointData,default)
S3method(pointData,matrix)
S3method(pointData,sf)
S3method(pointData,sfc_GEOMETRY)
S3method(pointData,sfc_POINT)
S3method(polygonData,Line)
S3method(polygonData,Lines)
S3method(polygonData,Polygon)
S3method(polygonData,Polygons)
S3method(polygonData,SharedData)
S3method(polygonData,SpatVector)
S3method(polygonData,SpatialLines)
S3method(polygonData,SpatialLinesDataFrame)
S3method(polygonData,SpatialPolygons)
S3method(polygonData,SpatialPolygonsDataFrame)
S3method(polygonData,default)
S3method(polygonData,map)
S3method(polygonData,matrix)
S3method(polygonData,sf)
S3method(polygonData,sfc)
S3method(polygonData,sfg)
S3method(toPaletteFunc,"function")
S3method(toPaletteFunc,character)
S3method(toPaletteFunc,matrix)
S3method(to_multipolygon,Lines)
S3method(to_multipolygon,MULTILINESTRING)
S3method(to_multipolygon,MULTIPOLYGON)
S3method(to_multipolygon,Polygons)
S3method(to_multipolygon,default)
S3method(to_multipolygon_list,SpatialLines)
S3method(to_multipolygon_list,SpatialPolygons)
S3method(to_multipolygon_list,default)
S3method(to_multipolygon_list,sfc)
S3method(to_polygon,POLYGON)
S3method(to_polygon,default)
S3method(to_ring,LINESTRING)
S3method(to_ring,Line)
S3method(to_ring,Polygon)
S3method(to_ring,default)
export("%>%")
export(JS)
export(WMSTileOptions)
export(addAwesomeMarkers)
export(addCircleMarkers)
export(addCircles)
export(addControl)
export(addEasyButton)
export(addEasyButtonBar)
export(addGeoJSON)
export(addGraticule)
export(addLabelOnlyMarkers)
export(addLayersControl)
export(addLegend)
export(addMapPane)
export(addMarkers)
export(addMeasure)
export(addMiniMap)
export(addPolygons)
export(addPolylines)
export(addPopups)
export(addProviderTiles)
export(addRasterImage)
export(addRasterLegend)
export(addRectangles)
export(addScaleBar)
export(addSimpleGraticule)
export(addTerminator)
export(addTiles)
export(addTopoJSON)
export(addWMSTiles)
export(awesomeIconList)
export(awesomeIcons)
export(clearBounds)
export(clearControls)
export(clearGeoJSON)
export(clearGroup)
export(clearImages)
export(clearMarkerClusters)
export(clearMarkers)
export(clearPopups)
export(clearShapes)
export(clearTiles)
export(clearTopoJSON)
export(colorBin)
export(colorFactor)
export(colorNumeric)
export(colorQuantile)
export(createLeafletMap)
export(derivePoints)
export(derivePolygons)
export(dispatch)
export(easyButton)
export(easyButtonState)
export(evalFormula)
export(expandLimits)
export(expandLimitsBbox)
export(filterNULL)
export(fitBounds)
export(flyTo)
export(flyToBounds)
export(getMapData)
export(gridOptions)
export(groupOptions)
export(hideGroup)
export(highlightOptions)
export(iconList)
export(icons)
export(invokeMethod)
export(labelFormat)
export(labelOptions)
export(layersControlOptions)
export(leaflet)
export(leafletCRS)
export(leafletDependencies)
export(leafletMap)
export(leafletOptions)
export(leafletOutput)
export(leafletProxy)
export(leafletSizingPolicy)
export(makeAwesomeIcon)
export(makeIcon)
export(mapOptions)
export(markerClusterOptions)
export(markerOptions)
export(pathOptions)
export(popupOptions)
export(previewColors)
export(projectRasterForLeaflet)
export(providerTileOptions)
export(providers)
export(providers.details)
export(removeControl)
export(removeGeoJSON)
export(removeImage)
export(removeLayersControl)
export(removeMarker)
export(removeMarkerCluster)
export(removeMarkerFromCluster)
export(removeMeasure)
export(removePopup)
export(removeScaleBar)
export(removeShape)
export(removeTiles)
export(removeTopoJSON)
export(renderLeaflet)
export(safeLabel)
export(scaleBarOptions)
export(setMaxBounds)
export(setView)
export(showGroup)
export(tileOptions)
export(validateCoords)
import(crosstalk)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(htmlwidgets,JS)
importFrom(magrittr,"%>%")
importFrom(methods,substituteDirect)
importFrom(rlang,is_installed)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(utils,getFromNamespace)
importFrom(utils,packageVersion)
