---
name: Bug report
about: Create a report to help us improve

---

<!--
Thanks for taking the time to open an issue!
Please provide a general summary of the issue in the title above .
-->

- [ ] I've looked at the [documentation](http://leafletjs.com/reference.html) to make sure the behavior is documented and expected
- [ ] I'm sure this is a Leaflet code issue, not an issue with my own code nor with the framework I'm using (Cordova, Ionic, Angular, React…)
- [ ] I've searched through the issues to make sure it's not yet reported

**Steps to reproduce**
Steps to reproduce the behavior:
- step 1
- step 2
- ...

**Expected behavior**
<!-- A clear and concise description of what you expected to happen. -->

**Current behavior**
<!-- A clear and concise description of what is actually happening. -->

**Environment**
- Leaflet version:
- Browser (with version):
- OS/Platform (with version):

**Additional context**
<!-- Add any other context about the problem here. -->

**Minimal example reproducing the issue**

Please create an example using https://leafletjs.com/edit.html or any other jsfiddle-like site.

- [ ] this example is as simple as possible
- [ ] this example does not rely on any third party code
