---
layout: post
title: Leaflet 1.2.0 has been released
description: a new bugfix release
author: Per Liedman
authorsite: http://www.liedman.net
---

Leaflet 1.2.0 has just been released. The major reason for this release is to address an unfortunate regression in the 1.1.0 release, [causing trouble with several plugins](https://github.com/Leaflet/Leaflet/issues/5589). Traditionally, Leaflet plugins has altered and added to Leaflet's namespace (the `L` global), something which is no longer allowed after Leaflet was rebuilt on ES6 modules (an imported module is read-only). To preserve backwards compatibility, we have made a workaround to make the Leaflet namespace and its contents mutable again.

For the future, we expect to work out a new recommendation for authoring Leaflet plugins, that takes into account how modern JavaScript is built with ES6 modules, instead of modifying the Leaflet namespace.

As usual, we also managed to close off a number of other bugs and make a couple of minor improvements, all with the help of our many contributors - a big thank you to all who contributed to the release this summer! See the full [changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md) for details.

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
