---
layout: post
title: Announcing Leaflet 1.3.4
description: New patch release is out
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.3.4 is out!

This release contains some bugfixes and improvements :)
Big thanks to all contributors who made this release possible!

Changelog is available [here](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

Want to receive notification when new Leaflet release is available? Subscribe to [this issue](https://github.com/Leaflet/Leaflet/issues/6295).

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
