---
name: Support
about: I need support with Leaflet

---

--------------^ Click "Preview" tab for a nicer view!

We use GitHub as an issue tracker.
For usage and support questions, please check out resources below:

1. Read Leaflet documentation: https://leafletjs.com
2. For support questions like "How can I do X with Leaflet?" please search or ask questions on StackOverflow or StackExchange using Leaflet tag:
  - https://stackoverflow.com/questions/tagged/leaflet
  - https://gis.stackexchange.com/questions/tagged/leaflet

Thanks!
