---
layout: post
title: Announcing Leaflet 1.5.1
description: Hotfix release is out! 
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.5.1 is out!

This is a hotfix release, which fixes module export regression in 1.5.0.

Changelog is available [here](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
