---
layout: post
title: Announcing Leaflet 1.0.2
description: Leaflet 1.0.2, a bugfix release, is out
author: Iván Sánchez Ortega
authorsite: http://ivan.sanchezortega.es
---

As part of our "we really promised a faster release cycle" vision, we are publishing Leaflet 1.0.2.

Compared to 1.0.1, this release fixes about a dozen bugs, and a couple new options. The full list of changes can be found on [the changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

As usual, check the [downloads page](https://leafletjs.com/download.html) to get this release.

### Next plans?

Now, Leaflet uses a set of scripts to put a lot of files together. While this has been reliable for years, we want to embrace some of the features of contemporary JavaScript.

We have been working on reorganizing the codebase to implement ES6 modules. This means a cleaner, easier to understand build system, and slightly smaller file sizes thanks to [RollupJS](http://rollupjs.org/).

We aim for a 1.1.0 release with the new rollup builds. Even though it's not a very exciting development, this will pave the way for experimenting with new ways of having Leaflet plugins.


Cheers,<br>
The Leaflet team.
