---
layout: post
title: Announcing Leaflet 1.3.0
description: a new bugfix release
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Long awaited Leaflet 1.3.0 has just been released!

This release contains a lot of bugfixes, improvements and a couple new options.
Big thanks to all contributors who made this release possible! See the full [changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md) for details.

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
