---
layout: post
title: Announcing Leaflet 1.5.0
description: New release is out! 
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.5.0 is out!

This release brings some new features, as well as bugfixes and improvements!

Here are some highlights:
- new `keepAspectRatio` option for `VideoOverlay`
- support for `keydown` and `keyup` events
- new `shadowPane` option for `Marker`
- fixed layers controls state when using multiple maps
- update attribution link to HTTPS

Big thanks to all contributors who made this release possible!

Changelog is available [here](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
