---
layout: post
title: Announcing Leaflet 1.3.1
description: a new bugfix release
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.3.1 has just been released!

This release fixes `L.TileLayer` regression, introduced in 1.3.0. Oops!

See [changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md) for details.

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
