---
layout: post
title: Announcing Leaflet 1.0.3
description: Leaflet 1.0.3, a bugfix release, is out
author: Iván Sánchez Ortega
authorsite: http://ivan.sanchezortega.es
---

Leaflet 1.0.3 is now out, with about a dozen bugfixes since 1.0.2.

One of the main highlights is the handling of `dblblick` events for web browsers
which support [`PointerEvent`s](https://developer.mozilla.org/en-US/docs/Web/API/PointerEvent).
Until now, the only browser which used `PointerEvent`s were Internet Explorer and Edge;
but now that Chrome has [enabled support in version 55](https://developers.google.com/web/updates/2016/11/nic55#pointer-events),
the Leaflet code for checking for double clicks and touchscreens had to change.

Leaflet 1.0.3 also improved the performance and behaviour of `L.Canvas` rendering,
backported a few fixes for Internet Explorer 8, and some miscellaneous fixes.

The full list of changes can be found on [the changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).


As usual, check the [downloads page](https://leafletjs.com/download.html) to get this release.


Cheers,<br>
The Leaflet team.
