---
layout: post
title: Announcing Leaflet 1.3.3
description: a new bugfix release
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.3.3 is out!

This release fixes global variable `L` not being exposed. See [#6238](https://github.com/Leaflet/Leaflet/issues/6238) for details.

Big thanks to our users for reporting this issue!

Changelog is available [here](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
