---
layout: post
title: Announcing Leaflet 1.7.0
description: Leaflet 1.7.0 now available
author: Iván Sánchez Ortega
authorsite: https://ivan.sanchezortega.es
---

During the last year or so, mainstream web browsers have subtly changed the way that touchscreens work; unfortunately, Leaflet 1.6.0 and previous versions now exhibit some quirks on touchscreens.

Leaflet 1.7.0 fixes that by bringing several changes to how `PointerEvent`s are detected and handled, and using passive touch event listeners when available.

Besides that, there's a bunch of small bug and documentation fixes, detailed in [the changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md). Thanks to everyone who sent a fix, no matter how small!

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
