---
layout: post
title: Announcing Leaflet 1.4.0
description: New Year's release is out! 
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.4.0 is out!

This minor version release brings new useful [Map.panInside](https://leafletjs.com/reference.html#map-paninside) method, as well as bugfixes and improvements! :)
Big thanks to all contributors who made this release possible!

Changelog is available [here](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md).

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Happy New Year,<br>
The Leaflet team.
