---
layout: post
title: Announcing Leaflet 1.3.2
description: a new bugfix release
author: Andrew Cherniavskii
authorsite: https://github.com/cherniavskii
---

Leaflet 1.3.2 is out!

This release contains some bugfixes and improvements :)
Big thanks to all contributors who made this release possible! See the full [changelog](https://github.com/Leaflet/Leaflet/blob/master/CHANGELOG.md) for details.

To get the new release, update your dependencies in your favorite package manager, or check the [downloads page](https://leafletjs.com/download.html).

Cheers,<br>
The Leaflet team.
